@@ -3,10 +3,7 @@
 
 #include <stdint-gcc.h>
 
-#define INDEX8 uint8_t
-#define INDEX16 uint16_t
-#define INDEX32 uint32_t
-#define INDEX64 uint64_t
+#define INDEX16 int16_t
 
 #define TEST_LOOP(DATA_TYPE, BITS)                                             \
   void __attribute__ ((noinline, noclone))                                     \
@@ -18,17 +15,17 @@
   }
 
 #define TEST_ALL(T)                                                            \
-  T (int8_t, 8)                                                                \
-  T (uint8_t, 8)                                                               \
-  T (int16_t, 16)                                                              \
-  T (uint16_t, 16)                                                             \
-  T (_Float16, 16)                                                             \
-  T (int32_t, 32)                                                              \
-  T (uint32_t, 32)                                                             \
-  T (float, 32)                                                                \
-  T (int64_t, 64)                                                              \
-  T (uint64_t, 64)                                                             \
-  T (double, 64)
+  T (int8_t, 16)                                                                \
+  T (uint8_t, 16)                                                               \
+  T (int16_t, 16)                                                               \
+  T (uint16_t, 16)                                                              \
+  T (_Float16, 16)                                                              \
+  T (int32_t, 16)                                                               \
+  T (uint32_t, 16)                                                              \
+  T (float, 16)                                                                 \
+  T (int64_t, 16)                                                               \
+  T (uint64_t, 16)                                                              \
+  T (double, 16)
 
 TEST_ALL (TEST_LOOP)
 
